@@ -41,10 +41,10 @@ class KFindPrivate;
  *  // This creates a find-next-prompt dialog if needed.
  *  m_find = new KFind(pattern, options, this);
  *
- *  // Connect highlight signal to code which handles highlighting
- *  // of found text.
- *  connect(m_find, SIGNAL(highlight(QString, int, int)),
- *          this, SLOT(slotHighlight(QString, int, int)));
+ *  // Connect textFound() signal to code which handles highlighting of found text.
+ *  connect(m_find, &KFind::textFound, this, [this](const QString &text, int matchingIndex, int matchedLength) {
+ *      slotHighlight(text, matchingIndex, matchedLength);
+ *  }));
  *  // Connect findNext signal - called when pressing the button in the dialog
  *  connect(m_find, SIGNAL(findNext()),
  *          this, SLOT(slotFindNext()));
@@ -128,7 +128,7 @@ public:
      * will notice if the find dialog is closed.
      */
     KFind(const QString &pattern, long options, QWidget *parent, QWidget *findDialog);
-    virtual ~KFind();
+    ~KFind() override;
 
     enum Result {
         NoMatch,
@@ -168,9 +168,10 @@ public:
     void setData(int id, const QString &data, int startPos = -1);
 
     /**
-     * Walk the text fragment (e.g. text-processor line, kspread cell) looking for matches.
-     * For each match, emits the highlight() signal and displays the find-again dialog
-     * proceeding.
+     * Walk the text fragment (e.g. in a text-processor line or spreadsheet
+     * cell ...etc) looking for matches.
+     * For each match, emits the textFound() signal and displays the find-again
+     * dialog to ask if the user wants to find the same text again.
      */
     Result find();
 
@@ -204,8 +205,8 @@ public:
     void setPattern(const QString &pattern);
 
     /**
-     * Return the number of matches found (i.e. the number of times
-     * the highlight signal was emitted).
+     * Returns the number of matches found (i.e. the number of times the textFound()
+     * signal was emitted).
      * If 0, can be used in a dialog box to tell the user "no match was found".
      * The final dialog does so already, unless you used setDisplayFinalDialog(false).
      */
@@ -223,7 +224,7 @@ public:
      * Virtual method, which allows applications to add extra checks for
      * validating a candidate match. It's only necessary to reimplement this
      * if the find dialog extension has been used to provide additional
-     * criterias.
+     * criteria.
      *
      * @param text  The current text fragment
      * @param index The starting index where the candidate match was found
@@ -291,6 +292,8 @@ public:
      * If the KFind::RegularExpression flag is set, the @p pattern will be iterpreted
      * as a regular expression (using QRegularExpression).
      *
+     * @note Unicode support is always enabled (by setting the QRegularExpression::UseUnicodePropertiesOption flag).
+     *
      * @param text The string to search in
      * @param pattern The pattern to search for
      * @param index  The index in @p text from which to start the search
@@ -332,14 +335,14 @@ public:
 
     /**
      * @return the current matching index (or -1).
-     * Same as the matchingIndex parameter passed to highlight.
+     * Same as the matchingIndex parameter passed to the textFound() signal.
      * You usually don't need to use this, except maybe when updating the current data,
      * so you need to call setData(newData, index()).
      */
     int index() const;
 
 Q_SIGNALS:
-
+#if KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(5, 81)
     /**
      * Connect to this signal to implement highlighting of found text during the find
      * operation.
@@ -352,23 +355,65 @@ Q_SIGNALS:
      * setData(), but can also be an earlier set data block.
      *
      * @see setData()
+     *
+     * @deprecated since 5.81, use the KFind::textFound(const QString &, int, int) signal instead.
      */
-    void highlight(const QString &text, int matchingIndex, int matchedLength);
+    KTEXTWIDGETS_DEPRECATED_VERSION(5, 81, "Use the KFind::textFound(const QString &, int, int) signal instead.")
+    void highlight(const QString &text, int matchingIndex, int matchedLength); // clazy:exclude=overloaded-signal
+#endif
 
+    /**
+     * Connect to this signal to implement highlighting of found text during the find
+     * operation.
+     *
+     * If you've set data with setData(id, text), use the textFoundAtId(int, int, int) signal.
+     *
+     * WARNING: If you're using the FindIncremental option, the text argument
+     * passed by this signal is not necessarily the data last set through
+     * setData(), but can also be an earlier set data block.
+     *
+     * @see setData()
+     *
+     * @since 5.81
+     */
+    void textFound(const QString &text, int matchingIndex, int matchedLength);
+
+#if KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(5, 81)
     /**
      * Connect to this signal to implement highlighting of found text during the find
      * operation.
      *
      * Use this signal if you've set your data with setData(id, text), otherwise
-     * use the signal with highlight(text, matchingIndex, matchedLength).
+     * use the textFound(text, matchingIndex, matchedLength) signal.
      *
      * WARNING: If you're using the FindIncremental option, the id argument
      * passed by this signal is not necessarily the id of the data last set
      * through setData(), but can also be of an earlier set data block.
      *
      * @see setData()
+     *
+     * @deprecated since 5.81, use the KFind::textFoundAtId(int id, int matchingIndex, int matchedLength) signal instead.
      */
-    void highlight(int id, int matchingIndex, int matchedLength);
+    KTEXTWIDGETS_DEPRECATED_VERSION(5, 81, "Use the KFind::textFoundAtId(int id, int matchingIndex, int matchedLength) signal instead.")
+    void highlight(int id, int matchingIndex, int matchedLength); // clazy:exclude=overloaded-signal
+#endif
+
+    /**
+     * Connect to this signal to implement highlighting of found text during
+     * the find operation.
+     *
+     * Use this signal if you've set your data with setData(id, text),
+     * otherwise use the textFound(text, matchingIndex, matchedLength) signal.
+     *
+     * WARNING: If you're using the FindIncremental option, the id argument
+     * passed by this signal is not necessarily the id of the data last set
+     * through setData(), but can also be of an earlier set data block.
+     *
+     * @see setData()
+     *
+     * @since 5.81
+     */
+    void textFoundAtId(int id, int matchingIndex, int matchedLength);
 
     // ## TODO docu
     // findprevious will also emit findNext, after temporarily switching the value
@@ -395,17 +440,14 @@ protected:
     QWidget *dialogsParent() const;
 
 protected:
-    KFind(KFindPrivate &dd, const QString &pattern, long options, QWidget *parent);
-    KFind(KFindPrivate &dd, const QString &pattern, long options, QWidget *parent, QWidget *findDialog);
+    KTEXTWIDGETS_NO_EXPORT KFind(KFindPrivate &dd, const QString &pattern, long options, QWidget *parent);
+    KTEXTWIDGETS_NO_EXPORT KFind(KFindPrivate &dd, const QString &pattern, long options, QWidget *parent, QWidget *findDialog);
 
 private:
     friend class KReplace;
     Q_DECLARE_PRIVATE_D(d, KFind)
     std::unique_ptr<class KFindPrivate> const d;
     // KF6 TODO: change private d to protected d_ptr, use normal Q_DECLARE_PRIVATE, remove friend
-
-    Q_PRIVATE_SLOT(d_func(), void _k_slotFindNext())
-    Q_PRIVATE_SLOT(d_func(), void _k_slotDialogClosed())
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KFind::SearchOptions)
